{-# LANGUAGE MagicHash #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module AbstractCurry.Curry_Select
  ( d_C_typeName, d_C_typeVis, d_C_typeCons, d_C_consName, d_C_consVis
  , d_C_isBaseType, d_C_isPolyType, d_C_isFunctionalType, d_C_isIOType
  , d_C_isIOReturnType, d_C_argTypes, d_C_resultType, d_C_tvarsOfType
  , d_C_modsOfType, d_C_funcName, d_C_funcVis, d_C_varsOfPat, d_C_varsOfExp
  , d_C_varsOfRhs, d_C_varsOfStat, d_C_varsOfLDecl, d_C_varsOfFDecl
  , d_C_varsOfRule, d_C_isPrelude )
  where

import Basics
import qualified AbstractCurry.Curry_Types
import qualified Curry_List
import qualified Curry_Prelude


d_C_typeName :: AbstractCurry.Curry_Types.C_CTypeDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_typeName x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CType x2 x3 x4 x5 -> x2
  AbstractCurry.Curry_Types.C_CTypeSyn x6 x7 x8 x9 -> x6
  AbstractCurry.Curry_Types.C_CNewType x10 x11 x12 x13 -> x10
  AbstractCurry.Curry_Types.Choice_C_CTypeDecl d i l r -> narrow d i
    (d_C_typeName l cd cs) (d_C_typeName r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeDecl d i xs -> narrows cs d i (\z ->
    d_C_typeName z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeDecl d c e -> guardCons d c
    (d_C_typeName e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.typeName" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.typeName" (showCons x1))

d_C_typeVis :: AbstractCurry.Curry_Types.C_CTypeDecl -> Cover -> ConstStore
  -> AbstractCurry.Curry_Types.C_CVisibility
d_C_typeVis x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CType x2 x3 x4 x5 -> x3
  AbstractCurry.Curry_Types.C_CTypeSyn x6 x7 x8 x9 -> x7
  AbstractCurry.Curry_Types.C_CNewType x10 x11 x12 x13 -> x11
  AbstractCurry.Curry_Types.Choice_C_CTypeDecl d i l r -> narrow d i
    (d_C_typeVis l cd cs) (d_C_typeVis r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeDecl d i xs -> narrows cs d i (\z ->
    d_C_typeVis z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeDecl d c e -> guardCons d c
    (d_C_typeVis e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.typeVis" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.typeVis" (showCons x1))

d_C_typeCons :: AbstractCurry.Curry_Types.C_CTypeDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CConsDecl
d_C_typeCons x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CType x2 x3 x4 x5 -> x5
  AbstractCurry.Curry_Types.C_CTypeSyn x6 x7 x8 x9 -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CNewType x10 x11 x12 x13 -> Curry_Prelude.OP_Cons
    x13 Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.Choice_C_CTypeDecl d i l r -> narrow d i
    (d_C_typeCons l cd cs) (d_C_typeCons r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeDecl d i xs -> narrows cs d i (\z ->
    d_C_typeCons z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeDecl d c e -> guardCons d c
    (d_C_typeCons e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.typeCons" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.typeCons" (showCons x1))

d_C_consName :: AbstractCurry.Curry_Types.C_CConsDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_consName x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CCons x2 x3 x4 -> x2
  AbstractCurry.Curry_Types.C_CRecord x5 x6 x7 -> x5
  AbstractCurry.Curry_Types.Choice_C_CConsDecl d i l r -> narrow d i
    (d_C_consName l cd cs) (d_C_consName r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CConsDecl d i xs -> narrows cs d i (\z ->
    d_C_consName z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CConsDecl d c e -> guardCons d c
    (d_C_consName e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CConsDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.consName" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.consName" (showCons x1))

d_C_consVis :: AbstractCurry.Curry_Types.C_CConsDecl -> Cover -> ConstStore
  -> AbstractCurry.Curry_Types.C_CVisibility
d_C_consVis x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CCons x2 x3 x4 -> x3
  AbstractCurry.Curry_Types.C_CRecord x5 x6 x7 -> x6
  AbstractCurry.Curry_Types.Choice_C_CConsDecl d i l r -> narrow d i
    (d_C_consVis l cd cs) (d_C_consVis r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CConsDecl d i xs -> narrows cs d i (\z ->
    d_C_consVis z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CConsDecl d c e -> guardCons d c
    (d_C_consVis e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CConsDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.consVis" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.consVis" (showCons x1))

d_C_isBaseType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isBaseType x1 cd cs = let x2 = Curry_Prelude.C_False
  in d_C__case_3 x2 x1 cd cs

d_C_isPolyType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isPolyType x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTVar x2 -> Curry_Prelude.C_True
  AbstractCurry.Curry_Types.C_CFuncType x3 x4 -> Curry_Prelude.d_OP_bar_bar
    (d_C_isPolyType x3 cd cs) (d_C_isPolyType x4 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CTCons x5 x6 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_any d_C_isPolyType cd cs) x6 cd cs
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C_isPolyType l cd cs) (d_C_isPolyType r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_isPolyType z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C_isPolyType e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select.isPolyType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.isPolyType" (showCons x1))

d_C_isFunctionalType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isFunctionalType x1 cd cs = let x2 = Curry_Prelude.C_False
  in d_C__case_2 x2 x1 cd cs

d_C_isIOType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isIOType x1 cd cs = let x2 = Curry_Prelude.C_False
  in d_C__case_1 x2 x1 cd cs

d_C_isIOReturnType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isIOReturnType x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTVar x2 -> Curry_Prelude.C_False
  AbstractCurry.Curry_Types.C_CFuncType x3 x4 -> Curry_Prelude.C_False
  AbstractCurry.Curry_Types.C_CTCons x5 x6 -> Curry_Prelude.d_OP_amp_amp
    (Curry_Prelude.d_OP_eq_eq x5 (AbstractCurry.Curry_Types.d_C_pre
    (Curry_Prelude.toCurryString "IO") cd cs) cd cs) (Curry_Prelude.d_OP_amp_amp
    (Curry_Prelude.d_OP_slash_eq (Curry_Prelude.d_C_head x6 cd cs)
    (AbstractCurry.Curry_Types.C_CTCons (AbstractCurry.Curry_Types.d_C_pre
    (Curry_Prelude.toCurryString "()") cd cs) Curry_Prelude.OP_List) cd cs)
    (Curry_Prelude.d_C_not (d_C_isFunctionalType (Curry_Prelude.d_C_head x6 cd
    cs) cd cs) cd cs) cd cs) cd cs
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C_isIOReturnType l cd cs) (d_C_isIOReturnType r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_isIOReturnType z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C_isIOReturnType e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select.isIOReturnType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.isIOReturnType" (showCons
    x1))

d_C_argTypes :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CTypeExpr
d_C_argTypes x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTVar x2 -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CTCons x3 x4 -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CFuncType x5 x6 -> Curry_Prelude.OP_Cons x5
    (d_C_argTypes x6 cd cs)
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C_argTypes l cd cs) (d_C_argTypes r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_argTypes z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C_argTypes e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select.argTypes" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.argTypes" (showCons x1))

d_C_resultType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover -> ConstStore
  -> AbstractCurry.Curry_Types.C_CTypeExpr
d_C_resultType x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTVar x2 -> AbstractCurry.Curry_Types.C_CTVar x2
  AbstractCurry.Curry_Types.C_CTCons x3 x4 -> AbstractCurry.Curry_Types.C_CTCons
    x3 x4
  AbstractCurry.Curry_Types.C_CFuncType x5 x6 -> d_C_resultType x6 cd cs
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C_resultType l cd cs) (d_C_resultType r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_resultType z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C_resultType e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select.resultType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.resultType" (showCons x1))

d_C_tvarsOfType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_tvarsOfType x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTVar x2 -> Curry_Prelude.OP_Cons x2
    Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CFuncType x3 x4 -> Curry_Prelude.d_OP_plus_plus
    (d_C_tvarsOfType x3 cd cs) (d_C_tvarsOfType x4 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CTCons x5 x6 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_tvarsOfType cd cs) x6 cd cs
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C_tvarsOfType l cd cs) (d_C_tvarsOfType r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_tvarsOfType z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C_tvarsOfType e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select.tvarsOfType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.tvarsOfType" (showCons x1))

d_C_modsOfType :: AbstractCurry.Curry_Types.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_modsOfType x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTVar x2 -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CFuncType x3 x4 -> Curry_List.d_C_union
    (d_C_modsOfType x3 cd cs) (d_C_modsOfType x4 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CTCons x5 x6 -> d_C__case_0 x6 x5 cd cs
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C_modsOfType l cd cs) (d_C_modsOfType r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_modsOfType z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C_modsOfType e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select.modsOfType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.modsOfType" (showCons x1))

d_C_funcName :: AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_funcName x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CFunc x2 x3 x4 x5 x6 -> x2
  AbstractCurry.Curry_Types.C_CmtFunc x7 x8 x9 x10 x11 x12 -> x8
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_C_funcName l cd cs) (d_C_funcName r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C_funcName z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_C_funcName e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.funcName" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.funcName" (showCons x1))

d_C_funcVis :: AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> AbstractCurry.Curry_Types.C_CVisibility
d_C_funcVis x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CFunc x2 x3 x4 x5 x6 -> x4
  AbstractCurry.Curry_Types.C_CmtFunc x7 x8 x9 x10 x11 x12 -> x10
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_C_funcVis l cd cs) (d_C_funcVis r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C_funcVis z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_C_funcVis e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.funcVis" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.funcVis" (showCons x1))

d_C_varsOfPat :: AbstractCurry.Curry_Types.C_CPattern -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_varsOfPat x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CPVar x2 -> Curry_Prelude.OP_Cons x2
    Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CPLit x3 -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CPComb x4 x5 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfPat cd cs) x5 cd cs
  AbstractCurry.Curry_Types.C_CPAs x6 x7 -> Curry_Prelude.OP_Cons x6
    (d_C_varsOfPat x7 cd cs)
  AbstractCurry.Curry_Types.C_CPFuncComb x8 x9 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfPat cd cs) x9 cd cs
  AbstractCurry.Curry_Types.C_CPLazy x10 -> d_C_varsOfPat x10 cd cs
  AbstractCurry.Curry_Types.C_CPRecord x11 x12 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap (Curry_Prelude.d_OP_dot d_C_varsOfPat
    Curry_Prelude.d_C_snd cd cs) cd cs) x12 cd cs
  AbstractCurry.Curry_Types.Choice_C_CPattern d i l r -> narrow d i
    (d_C_varsOfPat l cd cs) (d_C_varsOfPat r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CPattern d i xs -> narrows cs d i (\z ->
    d_C_varsOfPat z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CPattern d c e -> guardCons d c
    (d_C_varsOfPat e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CPattern d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfPat" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfPat" (showCons x1))

d_C_varsOfExp :: AbstractCurry.Curry_Types.C_CExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_varsOfExp x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CVar x2 -> Curry_Prelude.OP_Cons x2
    Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CLit x3 -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CSymbol x4 -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CApply x5 x6 -> Curry_Prelude.d_OP_plus_plus
    (d_C_varsOfExp x5 cd cs) (d_C_varsOfExp x6 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CLambda x7 x8 -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concatMap d_C_varsOfPat cd cs)
    x7 cd cs) (d_C_varsOfExp x8 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CLetDecl x9 x10 -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concatMap d_C_varsOfLDecl cd cs)
    x9 cd cs) (d_C_varsOfExp x10 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CDoExpr x11 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfStat cd cs) x11 cd cs
  AbstractCurry.Curry_Types.C_CListComp x12 x13 -> Curry_Prelude.d_OP_plus_plus
    (d_C_varsOfExp x12 cd cs) (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfStat cd cs) x13 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CCase x14 x15 x16 -> Curry_Prelude.d_OP_plus_plus
    (d_C_varsOfExp x15 cd cs) (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_OP_varsOfExp_dot_uscore_hash_lambda4 cd cs)
    x16 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CTyped x17 x18 -> d_C_varsOfExp x17 cd cs
  AbstractCurry.Curry_Types.C_CRecConstr x19 x20 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap (Curry_Prelude.d_OP_dot d_C_varsOfExp
    Curry_Prelude.d_C_snd cd cs) cd cs) x20 cd cs
  AbstractCurry.Curry_Types.C_CRecUpdate x21 x22 -> Curry_Prelude.d_OP_plus_plus
    (d_C_varsOfExp x21 cd cs) (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap (Curry_Prelude.d_OP_dot d_C_varsOfExp
    Curry_Prelude.d_C_snd cd cs) cd cs) x22 cd cs) cd cs
  AbstractCurry.Curry_Types.Choice_C_CExpr d i l r -> narrow d i (d_C_varsOfExp
    l cd cs) (d_C_varsOfExp r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CExpr d i xs -> narrows cs d i (\z ->
    d_C_varsOfExp z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CExpr d c e -> guardCons d c (d_C_varsOfExp
    e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CExpr d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfExp" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfExp" (showCons x1))

d_OP_varsOfExp_dot_uscore_hash_lambda4 :: Curry_Prelude.OP_Tuple2
  AbstractCurry.Curry_Types.C_CPattern AbstractCurry.Curry_Types.C_CRhs -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  Curry_Prelude.C_Int (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_varsOfExp_dot_uscore_hash_lambda4 x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.d_OP_plus_plus (d_C_varsOfPat
    x2 cd cs) (d_C_varsOfRhs x3 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_varsOfExp_dot_uscore_hash_lambda4 l cd cs)
    (d_OP_varsOfExp_dot_uscore_hash_lambda4 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_varsOfExp_dot_uscore_hash_lambda4 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_varsOfExp_dot_uscore_hash_lambda4 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfExp._#lambda4" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfExp._#lambda4"
    (showCons x1))

d_C_varsOfRhs :: AbstractCurry.Curry_Types.C_CRhs -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_varsOfRhs x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CSimpleRhs x2 x3 -> Curry_Prelude.d_OP_plus_plus
    (d_C_varsOfExp x2 cd cs) (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfLDecl cd cs) x3 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CGuardedRhs x4 x5 -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concatMap
    d_OP_varsOfRhs_dot_uscore_hash_lambda5 cd cs) x4 cd cs)
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concatMap d_C_varsOfLDecl cd cs)
    x5 cd cs) cd cs
  AbstractCurry.Curry_Types.Choice_C_CRhs d i l r -> narrow d i (d_C_varsOfRhs l
    cd cs) (d_C_varsOfRhs r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CRhs d i xs -> narrows cs d i (\z ->
    d_C_varsOfRhs z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CRhs d c e -> guardCons d c (d_C_varsOfRhs e
    cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CRhs d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfRhs" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfRhs" (showCons x1))

d_OP_varsOfRhs_dot_uscore_hash_lambda5 :: Curry_Prelude.OP_Tuple2
  AbstractCurry.Curry_Types.C_CExpr AbstractCurry.Curry_Types.C_CExpr -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  Curry_Prelude.C_Int (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_varsOfRhs_dot_uscore_hash_lambda5 x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.d_OP_plus_plus (d_C_varsOfExp
    x2 cd cs) (d_C_varsOfExp x3 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_varsOfRhs_dot_uscore_hash_lambda5 l cd cs)
    (d_OP_varsOfRhs_dot_uscore_hash_lambda5 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_varsOfRhs_dot_uscore_hash_lambda5 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_varsOfRhs_dot_uscore_hash_lambda5 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfRhs._#lambda5" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfRhs._#lambda5"
    (showCons x1))

d_C_varsOfStat :: AbstractCurry.Curry_Types.C_CStatement -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_varsOfStat x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CSExpr x2 -> d_C_varsOfExp x2 cd cs
  AbstractCurry.Curry_Types.C_CSPat x3 x4 -> Curry_Prelude.d_OP_plus_plus
    (d_C_varsOfPat x3 cd cs) (d_C_varsOfExp x4 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CSLet x5 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfLDecl cd cs) x5 cd cs
  AbstractCurry.Curry_Types.Choice_C_CStatement d i l r -> narrow d i
    (d_C_varsOfStat l cd cs) (d_C_varsOfStat r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CStatement d i xs -> narrows cs d i (\z ->
    d_C_varsOfStat z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CStatement d c e -> guardCons d c
    (d_C_varsOfStat e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CStatement d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfStat" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfStat" (showCons x1))

d_C_varsOfLDecl :: AbstractCurry.Curry_Types.C_CLocalDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_varsOfLDecl x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CLocalFunc x2 -> d_C_varsOfFDecl x2 cd cs
  AbstractCurry.Curry_Types.C_CLocalPat x3 x4 -> Curry_Prelude.d_OP_plus_plus
    (d_C_varsOfPat x3 cd cs) (d_C_varsOfRhs x4 cd cs) cd cs
  AbstractCurry.Curry_Types.C_CLocalVars x5 -> x5
  AbstractCurry.Curry_Types.Choice_C_CLocalDecl d i l r -> narrow d i
    (d_C_varsOfLDecl l cd cs) (d_C_varsOfLDecl r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CLocalDecl d i xs -> narrows cs d i (\z ->
    d_C_varsOfLDecl z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CLocalDecl d c e -> guardCons d c
    (d_C_varsOfLDecl e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CLocalDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfLDecl" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfLDecl" (showCons x1))

d_C_varsOfFDecl :: AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_varsOfFDecl x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CFunc x2 x3 x4 x5 x6 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfRule cd cs) x6 cd cs
  AbstractCurry.Curry_Types.C_CmtFunc x7 x8 x9 x10 x11 x12 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_varsOfRule cd cs) x12 cd cs
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_C_varsOfFDecl l cd cs) (d_C_varsOfFDecl r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C_varsOfFDecl z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_C_varsOfFDecl e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfFDecl" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfFDecl" (showCons x1))

d_C_varsOfRule :: AbstractCurry.Curry_Types.C_CRule -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_varsOfRule x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CRule x2 x3 -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concatMap d_C_varsOfPat cd cs)
    x2 cd cs) (d_C_varsOfRhs x3 cd cs) cd cs
  AbstractCurry.Curry_Types.Choice_C_CRule d i l r -> narrow d i (d_C_varsOfRule
    l cd cs) (d_C_varsOfRule r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CRule d i xs -> narrows cs d i (\z ->
    d_C_varsOfRule z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CRule d c e -> guardCons d c (d_C_varsOfRule
    e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CRule d info -> failCons d (traceFail
    "AbstractCurry.Select.varsOfRule" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select.varsOfRule" (showCons x1))

d_C_isPrelude :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isPrelude x1 cd cs = Curry_Prelude.d_OP_eq_eq x1
  (Curry_Prelude.toCurryString "Prelude") cd cs

d_C__case_0 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CTypeExpr
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_0 x6 x5 cd cs = case x5 of
  Curry_Prelude.OP_Tuple2 x7 x8 -> Curry_Prelude.d_OP_dollar
    (Curry_Prelude.d_C_foldr (acceptCs id Curry_List.d_C_union)
    (Curry_Prelude.OP_Cons x7 Curry_Prelude.OP_List)) (Curry_Prelude.d_C_map
    d_C_modsOfType x6 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_0 x6 l cd cs)
    (d_C__case_0 x6 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_0 x6
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_0 x6 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "AbstractCurry.Select._case_0" [show x6, show x5] info)
  _ -> failCons cd (consFail "AbstractCurry.Select._case_0" (showCons x5))

d_C__case_1 :: Curry_Prelude.C_Bool -> AbstractCurry.Curry_Types.C_CTypeExpr
  -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_1 x2 x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTCons x3 x4 -> Curry_Prelude.d_OP_eq_eq x3
    (AbstractCurry.Curry_Types.d_C_pre (Curry_Prelude.toCurryString "IO") cd cs)
    cd cs
  AbstractCurry.Curry_Types.C_CTVar x5 -> x2
  AbstractCurry.Curry_Types.C_CFuncType x6 x7 -> x2
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C__case_1 x2 l cd cs) (d_C__case_1 x2 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C__case_1 x2 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C__case_1 x2 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select._case_1" [show x2, show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select._case_1" (showCons x1))

d_C__case_2 :: Curry_Prelude.C_Bool -> AbstractCurry.Curry_Types.C_CTypeExpr
  -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_2 x2 x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CFuncType x3 x4 -> Curry_Prelude.C_True
  AbstractCurry.Curry_Types.C_CTVar x5 -> x2
  AbstractCurry.Curry_Types.C_CTCons x6 x7 -> x2
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C__case_2 x2 l cd cs) (d_C__case_2 x2 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C__case_2 x2 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C__case_2 x2 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select._case_2" [show x2, show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select._case_2" (showCons x1))

d_C__case_3 :: Curry_Prelude.C_Bool -> AbstractCurry.Curry_Types.C_CTypeExpr
  -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_3 x2 x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CTCons x3 x4 -> Curry_Prelude.d_C_null x4 cd cs
  AbstractCurry.Curry_Types.C_CTVar x5 -> x2
  AbstractCurry.Curry_Types.C_CFuncType x6 x7 -> x2
  AbstractCurry.Curry_Types.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C__case_3 x2 l cd cs) (d_C__case_3 x2 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C__case_3 x2 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C__case_3 x2 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurry.Select._case_3" [show x2, show x1] info)
  _ -> failCons cd (consFail "AbstractCurry.Select._case_3" (showCons x1))

